//------------------------------------------------------------------------
//  Button Menu
//------------------------------------------------------------------------
//
//  Visplane Explorer
//
//  Copyright (C) 2012 Andrew Apted
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//------------------------------------------------------------------------

#include "headers.h"


//
// UI_Menu Constructor
//
UI_Menu::UI_Menu(int X, int Y, int W, int H, const char *label) : 
    Fl_Group(X, Y, W, H, label)
{
	end();  // cancel begin() in Fl_Group constructor

	box(FL_FLAT_BOX);

	color(FL_DARK3);


	X += 6;  W -= 12;
	Y += 5;  H -= 10;

	int cx = X;
	int cy = Y;


	// ------- Main Menu -------

	Fl_Box *heading = new Fl_Box(FL_NO_BOX, cx, cy, W, 28, "Main Menu");

	heading->align(FL_ALIGN_LEFT | FL_ALIGN_INSIDE);
	heading->labeltype(FL_NORMAL_LABEL);
	heading->labelfont(FL_HELVETICA_BOLD);
	heading->labelsize(FL_NORMAL_SIZE + 2);

	add(heading);

	cy += heading->h() + 4;


	load_wad = new Fl_Button(X + 32, cy + 0,  120, 32, "Load WAD");
	load_wad->labelsize(FL_NORMAL_SIZE + 2);
  	load_wad->callback(load_callback, this);

	add(load_wad);

	cy += load_wad->h() + 8;


	set_map = new Fl_Button(X + 32, cy + 0,  120, 32, "Choose Map");
	set_map->labelsize(FL_NORMAL_SIZE + 2);
  	set_map->callback(map_callback, this);
	set_map->deactivate();

	add(set_map);

	cy += set_map->h() + 8 + 20;


#if 0
	save_image = new Fl_Button(X + 32, cy + 0,  120, 32, "Save Image");
	save_image->labelsize(FL_NORMAL_SIZE + 2);
//	save_image->callback(save_image_callback, this);

	add(save_image);

	cy += save_image->h() + 8 + 12;
#endif


	about = new Fl_Button(X + 32, cy + 0,  100, 32, "About");
	about->labelsize(FL_NORMAL_SIZE + 2);
	about->callback(about_callback, this);

	add(about);

	cy += about->h() + 8;


	quit = new Fl_Button(X + 32, cy + 0,  100, 32, "Quit");
	quit->labelsize(FL_NORMAL_SIZE + 2);
	quit->callback(quit_callback, this);

	add(quit);

	cy += quit->h() + 8;


	resizable(NULL);
}


//
// UI_Menu Destructor
//
UI_Menu::~UI_Menu()
{
}


void UI_Menu::DisableLoadWAD()
{
	load_wad->deactivate();
}


void UI_Menu::EnableSetMap()
{
	set_map->activate();
}


void UI_Menu::DisableSetMap()
{
	set_map->deactivate();
}


void UI_Menu::about_callback(Fl_Widget *, void *)
{
	DLG_AboutText();
}


void UI_Menu::quit_callback(Fl_Widget *, void *)
{
	want_quit = true;
}


void UI_Menu::load_callback(Fl_Widget *, void *)
{
	Fl_Native_File_Chooser chooser;

	chooser.title("Pick file to open");
	chooser.type(Fl_Native_File_Chooser::BROWSE_FILE);
	chooser.filter("Wads\t*.wad");

	// Show native chooser
	switch (chooser.show())
	{
		case -1:
			fl_alert("%s", chooser.errmsg());
			return;

		case 1:
			// cancelled
			return;

		default:
			break;  // OK
	}

	Main_TryLoadWAD(chooser.filename());
}


void UI_Menu::map_callback(Fl_Widget *, void *)
{
	const char *map_name = fl_input("Enter map name (e.g. MAP01 or E1M1)", "");

	// cancelled?
	if (! map_name || map_name[0] == 0)
		return;


	VPO_CloseMap();

	map_is_loaded = false;


	char buffer[MSG_BUF_LEN];

	strncpy(buffer, map_name, 8);
	buffer[8] = 0;

	// make map name uppercase
	for (char *p = buffer ; *p ; p++)
		*p = toupper(*p);

	Main_TrySetMap(map_name);
}


//--- editor settings ---
// vi:ts=4:sw=4:noexpandtab
