//------------------------------------------------------------------------
//  Settings Panel
//------------------------------------------------------------------------
//
//  Visplane Explorer
//
//  Copyright (C) 2012 Andrew Apted
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//------------------------------------------------------------------------

#include "headers.h"


//
// UI_Panel Constructor
//
UI_Panel::UI_Panel(int X, int Y, int W, int H, const char *label) : 
    Fl_Group(X, Y, W, H, label)
{
	end();  // cancel begin() in Fl_Group constructor

	box(FL_FLAT_BOX);

	color(FL_DARK3);


	X += 6;  W -= 12;
	Y += 5;  H -= 10;

	int cx = X;
	int cy = Y;


	// ------- Main Menu -------

	Fl_Box *heading = new Fl_Box(FL_NO_BOX, cx, cy, W, 28, "Settings");

	heading->align(FL_ALIGN_LEFT | FL_ALIGN_INSIDE);
	heading->labeltype(FL_NORMAL_LABEL);
	heading->labelfont(FL_HELVETICA_BOLD);
	heading->labelsize(FL_NORMAL_SIZE + 2);

	add(heading);

	cy += heading->h() + 8;


	view = new Fl_Choice(X + 90, cy + 0,  100, 26, "View:");
	view->align(FL_ALIGN_LEFT);
	view->labelsize(FL_NORMAL_SIZE + 2);
	view->add("Visplanes|Drawsegs|Solidsegs|Openings");
	view->value(0);
  	view->callback(view_callback, this);

	add(view);

	cy += view->h() + 8 + 16;



	int hint_y = y() + h() - 40;

	Fl_Box *hint = new Fl_Box(FL_NO_BOX, cx, hint_y, W, 28, "Press TAB to toggle map");

	hint->align(FL_ALIGN_LEFT | FL_ALIGN_INSIDE);
	hint->labeltype(FL_NORMAL_LABEL);

	add(hint);
	


	resizable(NULL);
}


//
// UI_Panel Destructor
//
UI_Panel::~UI_Panel()
{
}


void UI_Panel::view_callback(Fl_Widget *, void *)
{
	// clear 'Count' widget on infobar
	main_win->panel->ShowDatum(DATUM_UNSET);
}


char UI_Panel::GetMode() const
{
	if (view->value() == 0) return 'v';
	if (view->value() == 1) return 'd';
	if (view->value() == 2) return 's';
	if (view->value() == 3) return 'o';

	return '?';
}


void UI_Panel::SetMode(char mode)
{
	int new_mode = 0;

	switch (mode)
	{
		case 'v': new_mode = 0; break;
		case 'd': new_mode = 1; break;
		case 's': new_mode = 2; break;
		case 'o': new_mode = 3; break;

		default: /* unknown */ return;
	}

	if (new_mode != view->value())
		main_win->canvas->redraw();

	view->value(new_mode);

	view_callback(view, NULL);
}


void UI_Panel::ShowDatum(datum_t d)
{
	switch (d)
	{
		case DATUM_UNSET:
		case DATUM_VOID:
			main_win->infobar->SetCount("");
			return;

		case DATUM_CLOSED:
			main_win->infobar->SetCount("Closed");
			return;

		case DATUM_OVERFLOW:
			main_win->infobar->SetCount("Extreme!");
			return;

		default:  // a normal value
			break;
	}

	int visplanes = DATUM_GET_VISPLANES(d);
	int drawsegs  = DATUM_GET_DRAWSEGS(d);
	int openings  = DATUM_GET_OPENINGS(d);
	int solidsegs = DATUM_GET_SOLIDSEGS(d);

	bool was_more = false;

	switch (GetMode())
	{
		case 'v':
			was_more = ((d & 0xFF) == 250);
			main_win->infobar->SetCount(visplanes, was_more, limit_of_visplanes);
			break;

		case 'd':
			was_more = (((d >> 8) & 0xFF) == 250);
			main_win->infobar->SetCount(drawsegs, was_more, limit_of_drawsegs);
			break;

		case 's':
			main_win->infobar->SetCount(solidsegs, false, limit_of_solidsegs);
			break;

		case 'o':
			was_more = (((d >> 16) & 0xFF) == 250);
			main_win->infobar->SetCount(openings, was_more, limit_of_openings);
			break;

		default:
			break;
	}
}


//--- editor settings ---
// vi:ts=4:sw=4:noexpandtab
