//------------------------------------------------------------------------
//  Main Window
//------------------------------------------------------------------------
//
//  Visplane Explorer
//
//  Copyright (C) 2012 Andrew Apted
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//------------------------------------------------------------------------

#include "headers.h"

#if (FL_MAJOR_VERSION != 1 ||  \
     FL_MINOR_VERSION != 3 ||  \
     FL_PATCH_VERSION < 0)
#error "Require FLTK version 1.3.0 or later"
#endif


UI_MainWin *main_win;


#define PANEL_W  220
#define MENU_H   240

#define WINDOW_MIN_W  620
#define WINDOW_MIN_H  440

#define WINDOW_MAX_W  (CANVAS_MAX_W + PANEL_W)
#define WINDOW_MAX_H  (CANVAS_MAX_H)

#define BG_COLOR  fl_rgb_color(0x66, 0x5E, 0x55)


static void main_win_close_CB(Fl_Widget *w, void *data)
{
	want_quit = true;
}


//
// MainWin Constructor
//
UI_MainWin::UI_MainWin() :
    Fl_Double_Window(WINDOW_MIN_W, WINDOW_MIN_H, VPOZOOM_TITLE),
    cursor_shape(FL_CURSOR_DEFAULT)
{
	end(); // cancel begin() in Fl_Group constructor

	size_range(WINDOW_MIN_W, WINDOW_MIN_H,
	           WINDOW_MAX_W, WINDOW_MAX_H);

	callback((Fl_Callback *) main_win_close_CB);

	color(BG_COLOR, BG_COLOR);


	bool panel_on_right = true;

	int cx = panel_on_right ? 0 : PANEL_W;
	int px = panel_on_right ? w() - PANEL_W : 0;

	int ey = h() - 28;


	canvas = new UI_Canvas(cx, 0, w() - PANEL_W, ey);
	add(canvas);

	menu = new UI_Menu(px, 0, PANEL_W, MENU_H);
	add(menu);

	panel = new UI_Panel(px, MENU_H+4, PANEL_W, ey - MENU_H - 8);
	add(panel);

	infobar = new UI_InfoBar(0, ey, w(), 28);
	add(infobar);


	resizable(canvas);
}


//
// MainWin Destructor
//
UI_MainWin::~UI_MainWin()
{ }


void UI_MainWin::SetCursor(Fl_Cursor shape)
{
	if (shape == cursor_shape)
		return;

	cursor_shape = shape;

	cursor(shape);
}


#if 0  // FIXME !!!!
void UI_MainWin::SetTitle(Wad_file *wad)
{
	static char title_buf[FL_PATH_MAX];

	const char *wad_name;
	
	if (wad)
	{
		wad_name = wad->PathName();
		wad_name = fl_filename_name(wad_name);

		sprintf(title_buf, "%s (%s)", wad_name, Level_name);
	}
	else
	{
		strcpy(title_buf, "Unsaved Map");
	}

	strcat(title_buf, " - Eureka v" EUREKA_VERSION);

	label(title_buf);

	info_bar->SetMap(Level_name, "");
}
#endif


//--- editor settings ---
// vi:ts=4:sw=4:noexpandtab
